@@ -1,7 +1,7 @@
 #!/bin/sh
 
-#Copyright (C) since 2011 NEC Corporation
-# version 1.0
+#Copyright (C) since 2012 NEC Corporation
+# version 2.0
 #
 #<License>
 #
@@ -12,20 +12,38 @@
 
 # bash configuration
 SCRIPT_DIR=$(cd $(dirname $0);pwd)
-. ${SCRIPT_DIR}/install.cfg
+. ${SCRIPT_DIR}/install.cfg || exit -1
 
 USER=`/usr/bin/whoami`
 
+. ${SCRIPT_DIR}/lib/ja_install.lng || exit -1
+
 function exitLog() {
   date +"### Hinemos Web Client インストーラー ended at %Y-%m-%d %H:%M:%S ###" >> ${INSTALL_LOG}
 }
 
-trap exitLog 0
+checkUser() {
+    echo
+    echo "${MSG_I002}"
+
+    if [ "x"$USER != "xroot" ] ; then
+	echo "[NG]"
+	echo "${MSG_E002}"
+	echo "${MSG_E004}"; return 1
+    fi
+
+    echo "[OK]"
+}
+
 
 ########################################
 # SHELL
 ########################################
 
+checkUser || exit 2
+
+trap exitLog 0
+
 date +"### Hinemos Web Client インストーラー started at %Y-%m-%d %H:%M:%S ###" >> ${INSTALL_LOG}
 ${SCRIPT_DIR}/install_all.sh ja 2>&1 | tee -ai ${INSTALL_LOG}
-exit $?
\ No newline at end of file
+exit $?
