@@ -1,7 +1,7 @@
 #!/bin/sh
 
-#Copyright (C) since 2011 NEC Corporation
-# version 1.0
+#Copyright (C) since 2012 NEC Corporation
+# version 2.0
 #
 # <License>
 #
@@ -16,19 +16,38 @@ SCRIPT_DIR=$(cd $(dirname $0);pwd)
 
 USER=`/usr/bin/whoami`
 
+. ${SCRIPT_DIR}/lib/en_uninstall.lng || exit -1
+
 function sigintHandle() {
   echo "Uninstaller using critical file operations."
   echo "Don't interrupt."
 }
 
-trap sigintHandle 2
+checkUser() {
+    echo
+    echo "${MSG_I001}"
+
+    if [ "x"$USER != "xroot" ] ; then
+	echo "[NG]"
+	echo "${MSG_E001}"
+	echo "${MSG_I002}"; return 1
+    fi
+
+    echo "[OK]"
+}
+
 
 ########################################
 # SHELL
 ########################################
 
+checkUser || exit 2
+
+trap sigintHandle 2
+
 date +"### Hinemos Web uninstaller started at %Y-%m-%d %H:%M:%S ###" >> ${UNINSTALL_LOG}
-${SCRIPT_DIR}/uninstaller_all.sh en 2>&1 | tee -a ${UNINSTALL_LOG}
+${SCRIPT_DIR}/uninstall_all.sh en 2>&1 | tee -a ${UNINSTALL_LOG}
 date +"### Hinemos Web uninstaller ended at %Y-%m-%d %H:%M:%S ###" >> ${UNINSTALL_LOG}
 
 exit $?
+
